@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 """plist
 """
-import base64
 from collections import OrderedDict
+from xml.dom.expatbuilder import parseString
+from xml.dom.minidom import Element, Document, DocumentType
+import base64
 import datetime
 import os
 import shutil
 import struct
 import sys
-from xml.dom.expatbuilder import parseString
-from xml.dom.minidom import Element, Document, DocumentType
 import zipfile
 
 
@@ -57,10 +57,20 @@ class UID(int):
     __repr__ = __str__
 
 
-class Data(bytes):
+class Data(str):
 
     def __init__(self, val):
-        super(Data, self).__init__(val)
+        super(Data, self).__init__()
+        self._raw = None
+
+    @property
+    def raw(self):
+        if self._raw is None:
+            if PY2:
+                self._raw = base64.decodestring(self)
+            else:
+                self._raw = base64.decodebytes(self.encode("ascii"))
+        return self._raw
 
 
 class PlistInfo(OrderedDict):
@@ -71,6 +81,10 @@ class PlistInfo(OrderedDict):
         self._parse()
         super(PlistInfo, self).__init__(self._objs[0])
 
+    @property
+    def format(self):
+        return self._get_fmt()
+
     @classmethod
     def from_file(cls, plist_file):
         if not os.path.exists(plist_file):
@@ -177,7 +191,7 @@ class PlistInfo(OrderedDict):
             obj_size, length_size = self._get_size(token_l, start)
             start += length_size
             end = start + obj_size
-            result = self._binary_data[start:end]
+            result = Data(self._binary_data[start:end])
         elif token_h == 0x50:  # ascii string
             obj_size, length_size = self._get_size(token_l, start)
             start += length_size
@@ -458,11 +472,15 @@ class PlistInfo(OrderedDict):
         elif node_type == "array":
             node_value = []
         elif node_type == "data":
-            node_value = base64.decodestring(node.childNodes[0].nodeValue)
+            content = node.childNodes[0].nodeValue
+            if PY2:
+                node_value = Data(content)
+            else:
+                node_value = Data(content)
         elif node_type == "date":
             content = node.childNodes[0].nodeValue
             node_value = datetime.datetime.strptime(
-                content, "%Y%m%dT%H:%M:%SZ")
+                content, "%Y-%m-%dT%H:%M:%SZ")
         else:
             raise ValueError("unexpected node_type=%s" % node_type)
         return node_value
@@ -512,14 +530,13 @@ class PlistInfo(OrderedDict):
             data_node = dom.createElement("real")
             text_node = dom.createTextNode(str(data))
             data_node.appendChild(text_node)
-        elif isinstance(data, bytes):
+        elif isinstance(data, Data):
             data_node = dom.createElement("data")
-            data = base64.encodestring(data)
             text_node = dom.createTextNode(data)
             data_node.appendChild(text_node)
-        elif isinstance(data, datetime):
+        elif isinstance(data, datetime.datetime):
             data_node = dom.createElement("date")
-            data = data.strftime("%Y%m%dT%H:%M:%SZ")
+            data = data.strftime("%Y-%m-%dT%H:%M:%SZ")
             text_node = dom.createTextNode(data)
             data_node.appendChild(text_node)
         else:
